@@ -67,7 +67,7 @@ struct _XfceSettingsEditorBox
     GtkWidget         *button_edit;
     GtkWidget         *button_reset;
 
-    gint			   paned_pos;
+    gint               paned_pos;
 };
 
 
@@ -200,12 +200,12 @@ xfce_settings_editor_box_init (XfceSettingsEditorBox *self)
                                           CHANNEL_COLUMN_NAME, GTK_SORT_ASCENDING);
 
     self->props_store = gtk_tree_store_new (N_PROP_COLUMNS,
-											G_TYPE_STRING,
-											G_TYPE_STRING,
-											G_TYPE_STRING,
-											G_TYPE_STRING,
-											G_TYPE_BOOLEAN,
-											G_TYPE_VALUE);
+                                            G_TYPE_STRING,
+                                            G_TYPE_STRING,
+                                            G_TYPE_STRING,
+                                            G_TYPE_STRING,
+                                            G_TYPE_BOOLEAN,
+                                            G_TYPE_VALUE);
     gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (self->props_store),
                                           PROP_COLUMN_NAME, GTK_SORT_ASCENDING);
     self->paned = paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
@@ -218,7 +218,7 @@ xfce_settings_editor_box_init (XfceSettingsEditorBox *self)
     /* Style the GtkPaned */
     gtk_paned_set_wide_handle (GTK_PANED (paned), TRUE);
     provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (provider, 
+    gtk_css_provider_load_from_data (provider,
         "paned > separator.wide { background:transparent; }", -1, NULL);
     gtk_style_context_add_provider (gtk_widget_get_style_context (paned),
         GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
@@ -322,7 +322,7 @@ xfce_settings_editor_box_init (XfceSettingsEditorBox *self)
 
     button = gtk_button_new ();
     image = gtk_image_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image (GTK_BUTTON (button), GTK_IMAGE (image));
+    gtk_button_set_image (GTK_BUTTON (button), image);
     gtk_container_add (GTK_CONTAINER (bbox), button);
     gtk_button_box_set_child_non_homogeneous (GTK_BUTTON_BOX (bbox), button, TRUE);
     gtk_widget_set_tooltip_text (button, _("New property"));
@@ -335,7 +335,7 @@ xfce_settings_editor_box_init (XfceSettingsEditorBox *self)
 
     button = gtk_button_new ();
     image = gtk_image_new_from_icon_name ("document-edit-symbolic", GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image (button, image);
+    gtk_button_set_image (GTK_BUTTON (button), image);
     gtk_container_add (GTK_CONTAINER (bbox), button);
     gtk_button_box_set_child_non_homogeneous (GTK_BUTTON_BOX (bbox), button, TRUE);
     gtk_widget_set_tooltip_text (button, _("Edit selected property"));
@@ -348,7 +348,7 @@ xfce_settings_editor_box_init (XfceSettingsEditorBox *self)
 
     button = gtk_button_new ();
     image = gtk_image_new_from_icon_name ("document-revert-symbolic", GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image (button, image);
+    gtk_button_set_image (GTK_BUTTON (button), image);
     gtk_container_add (GTK_CONTAINER (bbox), button);
     gtk_button_box_set_child_non_homogeneous (GTK_BUTTON_BOX (bbox), button, TRUE);
     gtk_widget_set_tooltip_text (button, _("Reset selected property"));
@@ -859,7 +859,7 @@ xfce_settings_editor_box_channel_monitor_changed (XfconfChannel *channel,
 												  GtkWidget     *window)
 {
     GtkTextBuffer *buffer;
-    GTimeVal       timeval;
+    gint64         timeval;
     gchar         *str;
     GValue         str_value = { 0, };
     GtkTextIter    iter;
@@ -867,7 +867,7 @@ xfce_settings_editor_box_channel_monitor_changed (XfconfChannel *channel,
     buffer = g_object_get_data (G_OBJECT (window), "buffer");
     g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
 
-    g_get_current_time (&timeval);
+    timeval = g_get_real_time ();
 
     if (value != NULL && G_IS_VALUE (value))
     {
@@ -875,14 +875,14 @@ xfce_settings_editor_box_channel_monitor_changed (XfconfChannel *channel,
         if (g_value_transform (value, &str_value))
         {
             str = g_strdup_printf ("%ld: %s (%s: %s)\n",
-                                   timeval.tv_sec, property,
+                                   timeval / G_USEC_PER_SEC, property,
                                    G_VALUE_TYPE_NAME (value),
                                    g_value_get_string (&str_value));
         }
         else
         {
             str = g_strdup_printf ("%ld: %s (%s)\n",
-                                   timeval.tv_sec, property,
+                                   timeval / G_USEC_PER_SEC, property,
                                    G_VALUE_TYPE_NAME (value));
         }
         g_value_unset (&str_value);
@@ -890,7 +890,7 @@ xfce_settings_editor_box_channel_monitor_changed (XfconfChannel *channel,
     else
     {
         /* I18N: if a property is removed from the channel */
-        str = g_strdup_printf ("%ld: %s (%s)\n", timeval.tv_sec,
+        str = g_strdup_printf ("%ld: %s (%s)\n", timeval / G_USEC_PER_SEC,
                                property, _("reset"));
     }
 
@@ -940,7 +940,7 @@ xfce_settings_editor_box_channel_monitor (XfceSettingsEditorBox *self)
     GtkWidget     *textview;
     GtkWidget     *content_area;
     GtkTextBuffer *buffer;
-    GTimeVal       timeval;
+    gint64         timeval;
     gchar         *str;
     GtkTextIter    iter;
 
@@ -986,9 +986,9 @@ xfce_settings_editor_box_channel_monitor (XfceSettingsEditorBox *self)
     g_signal_connect (G_OBJECT (self->props_channel), "property-changed",
         G_CALLBACK (xfce_settings_editor_box_channel_monitor_changed), window);
 
-    g_get_current_time (&timeval);
+    timeval = g_get_real_time ();
     gtk_text_buffer_get_start_iter (buffer, &iter);
-    str = g_strdup_printf ("%ld: ", timeval.tv_sec);
+    str = g_strdup_printf ("%ld: ", timeval / G_USEC_PER_SEC);
     gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, str, -1, "monospace", NULL);
     g_free (str);
 
