@@ -160,7 +160,6 @@ xfce_settings_manager_queue_resize (XfceSettingsManagerDialog *dialog)
 {
     GList *li;
     DialogCategory *category;
-    GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (dialog));
 
     for (li = dialog->categories; li != NULL; li = li->next)
     {
@@ -168,36 +167,6 @@ xfce_settings_manager_queue_resize (XfceSettingsManagerDialog *dialog)
         gtk_widget_queue_resize (GTK_WIDGET (category->iconview));
     }
 
-    if (window == NULL)
-        return FALSE;
-
-    gdk_window_invalidate_rect (window, NULL, TRUE);
-
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    gdk_window_process_updates (window, TRUE);
-G_GNUC_END_IGNORE_DEPRECATIONS
-
-    return FALSE;
-}
-
-
-
-/* FIXME: This is a hacky patch to ensure the embedded icon views resize on change. */
-static gboolean
-xfce_settings_manager_queue_redraw (XfceSettingsManagerDialog *dialog)
-{
-    GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (dialog));
-    gint h, w;
-
-    if (window == NULL)
-        return FALSE;
-
-    h = gdk_window_get_height (window);
-    w = gdk_window_get_width (window);
-
-    gdk_window_resize (window, w, h+1);
-    gdk_window_resize (window, w, h);
-
     return FALSE;
 }
 
@@ -273,6 +242,7 @@ xfce_settings_manager_dialog_init (XfceSettingsManagerDialog *dialog)
     g_signal_connect (G_OBJECT (entry), "key-press-event",
         G_CALLBACK (xfce_settings_manager_dialog_entry_key_press), dialog);
     gtk_widget_show (entry);
+    gtk_widget_grab_focus (dialog->filter_entry);
 
     dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
@@ -684,7 +654,7 @@ xfce_settings_manager_dialog_go_back (XfceSettingsManagerDialog *dialog)
     gtk_widget_set_sensitive (dialog->button_back, FALSE);
     gtk_widget_set_sensitive (dialog->button_help, TRUE);
 
-    gtk_widget_set_sensitive (dialog->filter_entry, TRUE);
+    gtk_widget_show (dialog->filter_entry);
     gtk_entry_set_text (GTK_ENTRY (dialog->filter_entry), "");
     gtk_widget_grab_focus (dialog->filter_entry);
 
@@ -749,7 +719,7 @@ xfce_settings_manager_dialog_entry_changed (GtkWidget                 *entry,
             gtk_widget_set_visible (category->box, n_children > 0);
         }
 
-        g_idle_add ((GSourceFunc) xfce_settings_manager_queue_redraw, dialog);
+        g_idle_add ((GSourceFunc) xfce_settings_manager_queue_resize, dialog);
     }
     else
     {
@@ -861,7 +831,7 @@ xfce_settings_manager_dialog_plug_added (GtkWidget                 *socket,
     /* button sensitivity */
     gtk_widget_set_sensitive (dialog->button_back, TRUE);
     gtk_widget_set_sensitive (dialog->button_help, dialog->help_page != NULL);
-    gtk_widget_set_sensitive (dialog->filter_entry, FALSE);
+    gtk_widget_hide (dialog->filter_entry);
 
     /* plug startup complete */
     gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET(dialog)), NULL);
@@ -887,7 +857,7 @@ static void
 xfce_settings_manager_dialog_spawn (XfceSettingsManagerDialog *dialog,
                                     GarconMenuItem            *item)
 {
-    const gchar    *command;
+    gchar          *command;
     gboolean        snotify;
     GdkScreen      *screen;
     GdkDisplay     *display;
@@ -897,13 +867,22 @@ xfce_settings_manager_dialog_spawn (XfceSettingsManagerDialog *dialog,
     XfceRc         *rc;
     gboolean        pluggable = FALSE;
     gchar          *cmd;
+    gchar          *uri;
     GtkWidget      *socket;
     GdkCursor      *cursor;
 
     g_return_if_fail (GARCON_IS_MENU_ITEM (item));
 
     screen = gtk_window_get_screen (GTK_WINDOW (dialog));
-    command = garcon_menu_item_get_command (item);
+
+    /* expand the field codes */
+    uri = garcon_menu_item_get_uri (item);
+    command = xfce_expand_desktop_entry_field_codes (garcon_menu_item_get_command (item),
+                                                     NULL,
+                                                     garcon_menu_item_get_icon_name (item),
+                                                     garcon_menu_item_get_name (item),
+                                                     uri, FALSE);
+    g_free (uri);
 
     /* we need to read some more info from the desktop
      *  file that is not supported by garcon */
@@ -970,6 +949,8 @@ xfce_settings_manager_dialog_spawn (XfceSettingsManagerDialog *dialog,
             g_error_free (error);
         }
     }
+
+  g_free (command);
 }
 
 
@@ -1342,7 +1323,7 @@ xfce_settings_manager_dialog_menu_reload (XfceSettingsManagerDialog *dialog)
         g_error_free (error);
     }
 
-    g_idle_add ((GSourceFunc) xfce_settings_manager_queue_redraw, dialog);
+    g_idle_add ((GSourceFunc) xfce_settings_manager_queue_resize, dialog);
 }
 
 
